@@ -1,22 +1,35 @@
 package Pod::Elemental::Objectifier;
-our $VERSION = '0.091470';
+our $VERSION = '0.092500';
 
 use Moose;
 use Moose::Autobox;
 # ABSTRACT: it turns a Pod::Eventual event stream into objects
 
-use Pod::Elemental::Element::Command;
-use Pod::Elemental::Element::Nonpod;
-use Pod::Elemental::Element::Text;
+use namespace::autoclean;
 
+use Pod::Elemental::Element::Generic::Blank;
+use Pod::Elemental::Element::Generic::Command;
+use Pod::Elemental::Element::Generic::Nonpod;
+use Pod::Elemental::Element::Generic::Text;
+
+
+sub __class_for {
+  return {
+    blank    => 'Pod::Elemental::Element::Generic::Blank',
+    command  => 'Pod::Elemental::Element::Generic::Command',
+    nonpod   => 'Pod::Elemental::Element::Generic::Nonpod',
+    text     => 'Pod::Elemental::Element::Generic::Text',
+  };
+}
 
 sub element_class_for_event {
   my ($self, $event) = @_;
   my $t = $event->{type};
-  return 'Pod::Elemental::Element::Command' if $t eq 'command';
-  return 'Pod::Elemental::Element::Text'    if $t eq 'verbatim' or $t eq 'text';
-  return 'Pod::Elemental::Element::Nonpod'  if $t eq 'nonpod';
-  Carp::croak "unknown event type: $t";
+  my $class_for = $self->__class_for;
+
+  Carp::croak "unknown event type: $t" unless exists $class_for->{ $t };
+
+  return $class_for->{ $t };
 }
 
 
@@ -24,26 +37,20 @@ sub objectify_events {
   my ($self, $events) = @_;
   return $events->map(sub {
     Carp::croak("not a valid event") unless ref $_;
-    return if $_->{type} eq 'blank';
 
     my $class = $self->element_class_for_event($_);
 
     my %guts = (
-      type       => $_->{type},
       content    => $_->{content},
       start_line => $_->{start_line},
 
       ($_->{type} eq 'command' ? (command => $_->{command}) : ()),
     );
 
-    chomp for values %guts;
-
     $class->new(\%guts);
   });
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -56,7 +63,7 @@ Pod::Elemental::Objectifier - it turns a Pod::Eventual event stream into objects
 
 =head1 VERSION
 
-version 0.091470
+version 0.092500
 
 =head1 METHODS
 
@@ -66,7 +73,7 @@ This method returns the name of the class to be used for the given event.
 
 =head2 objectify_events
 
-    my $elements = $objectifier->objectify_events(\@events);
+  my $elements = $objectifier->objectify_events(\@events);
 
 Given an arrayref of POD events, this method returns an arrayref of
 Pod::Elemental::Element objects formed from the event stream.
@@ -80,7 +87,7 @@ Pod::Elemental::Element objects formed from the event stream.
 This software is copyright (c) 2009 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+the same terms as the Perl 5 programming language system itself.
 
 =cut 
 
